==> zbxe.beta.0.2.6.tgz: zbxe/modules/admin/lang/zh-CN.lang.php <==
<?php
    /**
     * @file   zh-CN.lang.php
     * @author zero (zero@nzeo.com)
     * @brief  简体中文语言包 (只收录基本内容)
     **/

    $lang->admin_info = '管理员信息';
    $lang->admin_index = '管理首页';

    $lang->module_category_title = array(
        'service' => '服务类模块',
        'manager' => '管理类模块',
        'utility' => '功能模块',
        'accessory' => '附加模块',
        'base' => '基本模块',
    );

    $lang->newest_news = "最新消息";

    $lang->env_setup = "环境设置";

    $lang->env_information = "环境信息";
    $lang->current_version = "安装版本";
    $lang->current_path = "安装路径";
    $lang->released_version = "最新版本";
    $lang->about_download_link = "官方网站已发布新版本。请点击download链接下载最新版本。";

    $lang->item_module = "模块目录";
    $lang->item_addon  = "插件目录";
    $lang->item_widget = "控件目录";
    $lang->item_layout = "布局目录";

    $lang->module_name = "模块名称";
    $lang->addon_name = "插件名称";
    $lang->version = "版本";
    $lang->author = "作者";
    $lang->table_count = "表格数";
    $lang->installed_path = "安装路径";

    $lang->cmd_shortcut_management = "编辑菜单";

    $lang->msg_is_not_administrator = '只有管理员才可以查看';
    $lang->msg_manage_module_cannot_delete = '模块，插件，布局，控件模块的快捷菜单是不能删除的。';
    $lang->msg_default_act_is_null = '没有指定默认管理员的动作，是不能添加到快捷菜单的。';

    $lang->welcome_to_zeroboard_xe = 'zeroboard XE 管理页面';
    $lang->about_admin_page = "后台管理页面未完成";
    $lang->about_lang_env = "可以设置显示给首次访问者的同一语言环境。修改语言环境后请点击 [保存] 按钮进行保存。";

    $lang->zeroboard_xe_user_links = '为用户提供的链接';
    $lang->zeroboard_xe_developer_links = '为开发人员提供的链接';

    $lang->xe_user_links = array(
        '韩国官方主页' => 'http://www.zeroboard.com',
        //'closebeta主页' => 'http://spring.zeroboard.com',
        //'模块下载地址' => 'http://www.zeroboard.com',
        //'插件下载地址' => 'http://www.zeroboard.com',
        //'控件下载地址' => 'http://www.zeroboard.com',
        //'模块皮肤下载地址' => 'http://www.zeroboard.com',
        //'控件皮肤下载地址' => 'http://www.zeroboard.com',
        //'布局皮肤下载地址' => 'http://www.zeroboard.com',
    );

    $lang->xe_developer_links = array(
        //'使用手册' => 'http://www.zeroboard.com/wiki/manual',
        'Developer 论坛' => 'http://spring.zeroboard.com',
        '问题跟踪' => 'http://trac.zeroboard.com',
        'SVN Repository' => 'http://svn.zeroboard.com',
        'doxygen document' => 'http://doc.zeroboard.com',
        'pdf 文件' => 'http://doc.zeroboard.com/zeroboard_xe.pdf',
    );

    $lang->zeroboard_xe_usefulness_module = '常用模块';
    $lang->xe_usefulness_modules = array(
        'dispEditorAdminIndex' => '编辑器管理',
        'dispDocumentAdminList' => '主题管理',
        'dispCommentAdminList' => '评论管理',
        'dispFileAdminList' => '附件管理',
        'dispPollAdminList' => '投票管理',
        'dispSpamfilterAdminConfig' => '垃圾过滤管理',
        'dispCounterAdminIndex' => '统计日志',

    );

    $lang->xe_license = 'Zeroboard XE遵循 GPL协议';
    $lang->about_shortcut = '可以删除添加到常用模块中的快捷菜单。';
?>

==> zbxe.beta.0.2.7.tgz: zbxe/modules/admin/lang/zh-CN.lang.php <==
<?php
    /**
     * @file   zh-CN.lang.php
     * @author zero (zero@nzeo.com)
     * @brief  简体中文语言包 (只收录基本内容)
     **/

    $lang->admin_info = '管理员信息';
    $lang->admin_index = '管理首页';

    $lang->module_category_title = array(
        'service' => '服务类模块',
        'manager' => '管理类模块',
        'utility' => '功能模块',
        'accessory' => '附加模块',
        'base' => '基本模块',
    );

    $lang->newest_news = "最新消息";

    $lang->env_setup = "系统设置";

    $lang->env_information = "系统信息";
    $lang->current_version = "安装版本";
    $lang->current_path = "安装路径";
    $lang->released_version = "最新版本";
    $lang->about_download_link = "官方网站已发布新版本。请点击download链接下载最新版本。";

    $lang->item_module = "模块目录";
    $lang->item_addon  = "插件目录";
    $lang->item_widget = "控件目录";
    $lang->item_layout = "布局目录";

    $lang->module_name = "模块名称";
    $lang->addon_name = "插件名称";
    $lang->version = "版本";
    $lang->author = "作者";
    $lang->table_count = "表格数";
    $lang->installed_path = "安装路径";

    $lang->cmd_shortcut_management = "编辑菜单";

    $lang->msg_is_not_administrator = '只有管理员才可以查看';
    $lang->msg_manage_module_cannot_delete = '模块，插件，布局，控件模块的快捷菜单是不能删除的。';
    $lang->msg_default_act_is_null = '没有指定默认管理员的动作，是不能添加到快捷菜单的。';

    $lang->welcome_to_zeroboard_xe = 'zeroboard XE 管理页面';
    $lang->about_admin_page = "后台管理页面未完成";
    $lang->about_lang_env = "可以设置显示给首次访问者的同一语言环境。修改语言环境后请点击 [保存] 按钮进行保存。";

    $lang->zeroboard_xe_user_links = '为用户提供的链接';
    $lang->zeroboard_xe_developer_links = '为开发人员提供的链接';

    $lang->xe_user_links = array(
        '韩国官方主页' => 'http://www.zeroboard.com',
        //'closebeta主页' => 'http://spring.zeroboard.com',
        //'模块下载地址' => 'http://www.zeroboard.com',
        //'插件下载地址' => 'http://www.zeroboard.com',
        //'控件下载地址' => 'http://www.zeroboard.com',
        //'模块皮肤下载地址' => 'http://www.zeroboard.com',
        //'控件皮肤下载地址' => 'http://www.zeroboard.com',
        //'布局皮肤下载地址' => 'http://www.zeroboard.com',
    );

    $lang->xe_developer_links = array(
        //'使用手册' => 'http://www.zeroboard.com/wiki/manual',
        'Developer 论坛' => 'http://spring.zeroboard.com',
        '问题跟踪' => 'http://trac.zeroboard.com',
        'SVN Repository' => 'http://svn.zeroboard.com',
        'doxygen document' => 'http://doc.zeroboard.com',
        'pdf 文件' => 'http://doc.zeroboard.com/zeroboard_xe.pdf',
    );

    $lang->zeroboard_xe_usefulness_module = '常用模块';
    $lang->xe_usefulness_modules = array(
        'dispEditorAdminIndex' => '编辑器管理',
        'dispDocumentAdminList' => '主题管理',
        'dispCommentAdminList' => '评论管理',
        'dispFileAdminList' => '附件管理',
        'dispPollAdminList' => '投票管理',
        'dispSpamfilterAdminConfig' => '垃圾过滤管理',
        'dispCounterAdminIndex' => '统计日志',

    );

    $lang->xe_license = 'Zeroboard XE遵循 GPL协议';
    $lang->about_shortcut = '可以删除添加到常用模块中的快捷菜单。';
?>
